/*
	$Id: CSVParser.h 1187 2018-11-15 15:40:14Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __CSVParser_h__
#define __CSVParser_h__

#include <librfcdal/SqlGlobal.h>

#include <string>
#include <vector>
#include <map>
#include <iostream>

namespace RfcDal
{
	class RFCDAL_EXPORT CSVParser
	{
		public:
			class RFCDAL_EXPORT Row : public std::vector<std::string>
			{
				public:
					Row();
					Row( const Row& row );
					Row( const std::vector<std::string>& row );

					Row& operator=( const std::vector<std::string>& strRow );
			};

			class RFCDAL_EXPORT Table : public std::vector<Row>
			{
				private:
					Row _headingS;
					
				public:
					void setHeadings( const Row& headingS );
					const Row& headings() const;
			};

		public:
			enum CSVState { UnquotedField,
							QuotedField,
							QuotedQuote
			};

			static Row readCSVRow( const std::string &row );
			static Table readCSVTable( std::istream &in, bool bRow0isHeadings = false );

	};
}

#endif /* !__CSVParser_h__ */
