/*
	$Id: SqlColumn.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlColumn_h__
#define __SqlColumn_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlAbstractColumn.h>
#include <librfcdal/SqlTable.h>
#include <librfcdal/SqlColumnPtr.h>

#include <string>
#include <vector>
#include <map>

namespace RfcDal
{
	class SqlQueryBase;

	class RFCDAL_EXPORT SqlColumn : public SqlAbstractColumn
	{
		private:
			std::string _strColumn;
			std::string _strAlias;
			SqlColumnPtr _value;

		public:
			SqlColumn();
			SqlColumn( const SqlColumn& column );
			SqlColumn( const std::string& strColumn, const std::string& strAlias = std::string() );
			SqlColumn( const SqlTable& table, const std::string& strColumn, const std::string& strAlias = std::string() );
			SqlColumn( SqlQueryBase* pquery, const std::string& strColumn, const std::string& strAlias = std::string() );
			SqlColumn( SqlQueryBase* pquery, const SqlTable& table, const std::string& strColumn, const std::string& strAlias = std::string() );
			virtual ~SqlColumn();

			const SqlColumn& operator=( const SqlColumn& column );

			const std::string& column() const;
			virtual std::string id() const;

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			void setValue( const SqlColumnPtr& value );
			const SqlColumnPtr& value() const;

	};

	class SqlColumnMap : public std::map<std::string, SqlColumn*>
	{
	};
};

#endif /* !__SqlColumn_h__ */
