/*
	$Id: SqlColumnPtr.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlColumnPtr_h__
#define __SqlColumnPtr_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlAbstractColumn.h>

#include <vector>

namespace RfcDal
{
	class SqlColumn;
	class SqlFunction;
	class SqlValue;
	class SqlGeospatialValue;
	class SqlExpression;

	class RFCDAL_EXPORT SqlColumnPtr : public SqlAbstractColumn
	{
		private:
			enum ColumnIs { columnInvalid, columnColumn, columnFunction, columnValue, columnGeospatialValue, columnExpression };

		private:
			SqlAbstractColumn* _pelement;
			ColumnIs _column;

		public:
			SqlColumnPtr();
			SqlColumnPtr( const SqlColumnPtr& column );
			SqlColumnPtr( const SqlColumn& column );
			SqlColumnPtr( const SqlFunction& column );
			SqlColumnPtr( const SqlValue& column );
			SqlColumnPtr( const SqlGeospatialValue& column );
			SqlColumnPtr( const SqlExpression& column );
			virtual ~SqlColumnPtr();

			const SqlColumnPtr& operator=( const SqlColumnPtr& column );

			bool isValid() const;

			virtual std::string id() const;

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			const SqlColumnPtr& value() const;
	};

	class RFCDAL_EXPORT SqlColumnPtrList : public std::vector<SqlColumnPtr>, public SqlElement
	{
		private:
			SqlElement::Distinct _distinct;

		public:
			SqlColumnPtrList();
			SqlColumnPtrList( const SqlColumnPtrList& list );
			virtual ~SqlColumnPtrList();

			const SqlColumnPtrList& operator=( const SqlColumnPtrList& list );

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			SqlElement::Distinct distinct() const;
			void setDistinct( SqlElement::Distinct distinct );
	};
};

#endif /* !__SqlColumnPtr_h__ */
