/*
	$Id: SqlCondition.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlCondition_h__
#define __SqlCondition_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlColumnPtr.h>
#include <librfcdal/SqlValue.h>
#include <librfcdal/SqlValuePtr.h>
#include <librfcdal/SqlText.h>
#include <librfcdal/SqlSelectStatement.h>

#include <string>

namespace RfcDal
{
	class RFCDAL_EXPORT SqlCondition : public SqlElement
	{
		public:
			enum Condition { condNone, condUnary, condUnaryNot, condNull, condNotNull,
								condEqual, condNotEqual, condLessThan, condGreaterThan,
								condLessThanOrEq, condGreaterThanOrEq, condLike, condNotLike,
								condIn, condNotIn, condAnd, condOr, condRLike, condNotRLike };

			class RFCDAL_EXPORT SqlConditionModifier
			{
				public:
					enum LikeModifier { likeBoth,	// %value%
										likeLeft,	// value%
										likeRight	// %value
									} ;

				private:
					LikeModifier _like;

				public:
					SqlConditionModifier();
					SqlConditionModifier( const SqlConditionModifier& modifier );
					SqlConditionModifier( LikeModifier like );
					virtual ~SqlConditionModifier();

					LikeModifier like() const;

					SqlConditionModifier& operator=( const SqlConditionModifier& modifier );
			};

		private:
			SqlColumnPtr _column;
			SqlColumnPtr _columnRHS;
			SqlValuePtr _valueRHS;
			Condition _condition;
			SqlConditionModifier _modifier;
			SqlValueList _valueS;
			SqlValuePtrList _valuePtrS;
			SqlSelectStatement _stSelect;
			bool _bUseSelect;

		public:
			SqlCondition();
			SqlCondition( const SqlCondition& condition );
			SqlCondition( Condition condition );
			SqlCondition( const SqlColumnPtr& column, Condition condition );
			SqlCondition( const SqlColumnPtr& column, const SqlColumnPtr& columnRHS, Condition condition );
			SqlCondition( const SqlColumnPtr& column, const SqlValue& value, Condition condition, const SqlConditionModifier& modifier /*= SqlConditionModifier()*/ );
			SqlCondition( const SqlColumnPtr& column, const SqlValueList& valueS, Condition condition = condIn );
			SqlCondition( const SqlColumnPtr& column, const SqlValuePtrList& valueS, Condition condition = condIn );
			SqlCondition( const SqlColumnPtr& column, const SqlSelectStatement& stSelect, Condition condition = condIn );
			virtual ~SqlCondition();

			const SqlCondition& operator=( const SqlCondition& condition );

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;
	};
};

#endif /* !__SqlCondition_h__ */
