/*
	$Id: SqlDate.h 1241 2018-12-03 15:54:49Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2009, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlDate_h__
#define __SqlDate_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlValue.h>

#include <string>

namespace Base4c
{
	class Date;
}

namespace RfcDal
{
	class RFCDAL_EXPORT SqlDate : public SqlValue
	{
		public:
			static const SqlDate eternity;

		private:
			int _nYear;
			int _nMonth;
			int _nDay;

		public:
			SqlDate( const std::string& strAlias = std::string() );
			SqlDate( int nYear, int nMonth, int nDay, const std::string& strAlias = std::string());
			SqlDate( const SqlDate& date, const std::string& strAlias = std::string() );
			virtual ~SqlDate();

			const SqlDate& operator=( const SqlDate& date );

			bool operator==( const SqlDate& date ) const;

			int year() const;
			int month() const;
			int day() const;

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			virtual SqlValue* copy() const;

			static SqlDate fromText( const std::string& strText );

			static SqlDate fromDate( const Base4c::Date dt, const std::string& strAlias = std::string() );
			Base4c::Date asDate();
	};
};

#endif /* !__SqlDate_h__ */
