/*
	$Id: SqlGSPoint.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlGSPoint_h__
#define __SqlGSPoint_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlGeospatialValue.h>

namespace RfcDal
{
	class RFCDAL_EXPORT SqlGSPoint : public SqlGeospatialValue
	{
		private:
			double _dX;
			double _dY;

		public:
			SqlGSPoint( const std::string& strAlias = std::string() );
			SqlGSPoint( const SqlGSPoint& point );
			SqlGSPoint( double dX, double dY, const std::string& strAlias = std::string() );
			virtual ~SqlGSPoint();

			const SqlGSPoint& operator=( const SqlGSPoint& point );

			double x() const;
			double y() const;

			virtual std::string id() const;
			virtual GeospatialType type() const;

			virtual std::string toWkt( Suppression suppression ) const;

			virtual SqlValue* copy() const;

			static SqlGSPoint fromText( const std::string& strText );

		protected:
			static SqlGSPoint fromText( const std::string& strText, bool bSubMulti );

			friend class SqlGSMultiPoint;
	};

	class SqlGSPointList : public std::vector<SqlGSPoint>
	{
	};

	/*
	pointListFromText
	creates a point list from text of the form:
		(x0 y0,x1 y1,...,xn yn)
	see also SqlGSPointList RfcDal::SqlGSMultiPoint::fromText
	*/
	SqlGSPointList pointListFromText( const std::string& strText );
};

#endif /* !__SqlGSPoint_h__ */
