/*
	$Id: SqlGSPolygon.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlGSPolygon_h__
#define __SqlGSPolygon_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlGSSimplePolygon.h>

namespace RfcDal
{
	class RFCDAL_EXPORT SqlGSPolygon : public SqlGeospatialValue
	{
		private:
			SqlGSSimplePolygon _poly;
			SqlGSSimplePolygonList _exclusionS;

		public:
			SqlGSPolygon( const std::string& strAlias = std::string() );
			SqlGSPolygon( const SqlGSPolygon& poly );
			SqlGSPolygon( const SqlGSSimplePolygon& poly, const std::string& strAlias = std::string() );
			virtual ~SqlGSPolygon();

			const SqlGSPolygon& operator=( const SqlGSPolygon& poly );

			void addExclusion( const SqlGSSimplePolygon& poly );
			const SqlGSSimplePolygon& polygon() const;
			const SqlGSSimplePolygonList& exclusions() const;

			virtual std::string id() const;
			virtual GeospatialType type() const;

			virtual std::string toWkt( Suppression suppression ) const;

			virtual SqlValue* copy() const;

			static SqlGSPolygon fromText( const std::string& strText, bool bSubMulti = false );
	};

	class SqlGSPolygonList : public std::vector<SqlGSPolygon>
	{
	};
};

#endif /* !__SqlGSPolygon_h__ */
