/*
	$Id: SqlGeospatialValue.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlGeospatialValue_h__
#define __SqlGeospatialValue_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlValue.h>

namespace RfcDal
{
	class RFCDAL_EXPORT SqlGeospatialValue : public SqlValue
	{
		private:
			std::string _strAlias;

		public:
			enum Suppression { suppressNone, suppressQuotes, suppressClass, suppressAll };
			enum GeospatialType { gsSimplePolygon = 0, gsPoint, gsMultiPoint, gsLinestring, gsMultiLinestring, gsPolygon, gsMultiPolygon };

		public:
			SqlGeospatialValue( const std::string& strAlias = std::string() );
			SqlGeospatialValue( const SqlGeospatialValue& value );
			virtual ~SqlGeospatialValue();

			const SqlGeospatialValue& operator=( const SqlGeospatialValue& value );

			virtual std::string id() const = 0;
			virtual GeospatialType type() const = 0;

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;
			virtual std::string toWkt( Suppression suppression ) const = 0;

			virtual SqlValue* copy() const = 0;

			static std::string type( GeospatialType in );

			static SqlGeospatialValue* fromText( const std::string& strText );

		protected:
			const std::string& alias() const;
//			void alias( const std::string& strAlias );
	};
};

#endif /* !__SqlGeospatialValue_h__ */
