/*
	$Id: SqlInterpretException.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2011, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlInterpretException_h__
#define __SqlInterpretException_h__

#if defined (RFCDALDB_EXPORT)
#	undef RFCDALDB_EXPORT
#endif /* RFCDALDB_EXPORT */

#if defined (LINUX)
#	define RFCDALDB_EXPORT
#elif defined (_WINDOWS)
#	include <windows.h>
#	if defined (LIBRFCDALINTERPRET_EXPORTS)
#		define RFCDALDB_EXPORT __declspec( dllexport )
#	else
#		define RFCDALDB_EXPORT __declspec( dllimport )
#	endif /* LIBRFCDAL_EXPORTS */
#endif /* LINUX */

#include <string>
#include <iostream>

namespace RfcDal
{
	const int nNOTSUPPORTED					= 1000;
	const int nSTDEXCEPTION					= 1001;
	const int nUNKEXCEPTION					= 1002;
	const int nBADXML						= 1101;
	const int nNORUNNODE					= 2001;
	const int nELEMNOTFOUND					= 3001;
	const int nELEMWITHOUTID				= 3002;
	const int nBADNODE						= 3003;
	const int nINAPPROPRIATE				= 3004;
	const int nCOMPOUNDWITHOUTCOMPOUND		= 4001;
	const int nCOMPOUNDBADCOMPOUND			= 4002;
	const int nCONDITIONWITHOUTCONDITION	= 4101;
	const int nCONDITIONBADCONDITION		= 4102;
	const int nLIKEWITHOUTLIKE				= 4201;
	const int nLIKEBADLIKE					= 4202;
	const int nCONDITIONMISSINGLHS			= 4301;
	const int nCONDITIONMISSINGRHS			= 4302;
	const int nJOINWITHOUTJOIN				= 5001;
	const int nJOINBADJOIN					= 5002;
	const int nJOINWITHOUTTABLE				= 5003;
	const int nJOINWITHOUTON				= 5004;
	const int nORDERWITHOUTCOLUMN			= 6001;
	const int nGROUPWITHOUTCOLUMN			= 6101;
	const int nCOLUMNWITHOUTNAME			= 7001;

	class RFCDALDB_EXPORT SqlInterpretException
	{
		private:
			int _nError;
			std::string _strExplanation;
			int _nLine;

		public:
			SqlInterpretException( int nError, const std::string& strExplanation, int nLine );
			virtual ~SqlInterpretException();

			int error() const;
			const std::string& explanation() const;
			int line() const;
	};
};

RFCDALDB_EXPORT std::ostream& operator<<( std::ostream& stream, const RfcDal::SqlInterpretException& e );

#endif /* !__SqlInterpretException_h__ */
