/*
	$Id: SqlInterval.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2009, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlInterval_h__
#define __SqlInterval_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlValue.h>

#include <string>

namespace RfcDal
{
	class RFCDAL_EXPORT SqlInterval : public SqlValue
	{
		public:
			enum IntervalUnit { unitUnknown = -1, unitMSecond, unitSecond, unitMinute, unitHour,
								unitDay, unitWeek, unitMonth, unitQuarter, unitYear };

		private:
			IntervalUnit _unit;
			int _nInterval;

		public:
			SqlInterval( const SqlInterval& interval, const std::string& strAlias = "" );
			SqlInterval( IntervalUnit unit, int nInterval, const std::string& strAlias = "" );
			virtual ~SqlInterval();

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			IntervalUnit unit() const;
			int interval() const;

			const SqlInterval& operator=( const SqlInterval& interval );

			virtual SqlValue* copy() const;

			static SqlInterval fromText( const std::string& strText );

			static IntervalUnit unitFromText( const std::string& strText );
			static const std::string unitToText( IntervalUnit unit );
	};
};

#endif /* !__SqlInterval_h__ */
