/*
	$Id: SqlJoin.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlJoin_h__
#define __SqlJoin_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlElement.h>
#include <librfcdal/SqlTable.h>
#include <librfcdal/SqlConditionPtr.h>

namespace RfcDal
{
	class SqlCondition;
	class SqlCompoundCondition;

	class RFCDAL_EXPORT SqlJoin : public SqlElement
	{
		public:
			enum Join { joinInner, joinOuter, joinLeft, joinRight };

		private:
			Join _join;
			SqlTable _table;
			SqlConditionPtr _pcondition;

		public:
			SqlJoin();
			SqlJoin( const SqlJoin& join );
			SqlJoin( const SqlTable& table, Join join, const SqlCondition& condition );
			SqlJoin( const SqlTable& table, Join join, const SqlCompoundCondition& condition );
			SqlJoin( const SqlTable& table, Join join, const SqlConditionPtr& condition );
			virtual ~SqlJoin();

			const SqlJoin& operator=( const SqlJoin& join );

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;
	};

	class SqlJoinList : public std::vector<SqlJoin>
	{
	};
};

#endif /* !__SqlJoin_h__ */
