/*
	$Id: SqlLanguage.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlLanguage_h__
#define __SqlLanguage_h__

#include <librfcdal/SqlGlobal.h>

#include <string>

namespace RfcDal
{
	class RFCDAL_EXPORT SqlLanguage
	{
		public:
			enum Database { databaseSuppress, databaseOptional, databaseMandatory };
			enum Schema { schemaOptional,
							schemaMandatory, schemaMandatoryIfDatabase, schemaMandatoryIfNoDatabase,
							schemaSuppress, schemaSuppressIfDatabase, schemaSuppressIfNoDatabase,
							schemaObliterate, schemaObliterateIfDatabase, schemaObliterateIfNoDatabase };
			enum CaseSensitivity { caseInsensitive, caseSensitive, caseForceUpper, caseForceLower };

			/*
				database
				Whether a database name is Mandatory, optional or should be suppressed

				schema
				How to handle a schema name

				caseSensitivity
				Whether or not the data souce is case sensitive and, in certain cases, whether
				a specific case should be enforced.

				escapeQuote
				Whether to escape a single quote with another single quote in text

				escapeSlash
				Whether to escape a backslash with another backslash in text

				columnAliasAs
				Whether to insert the syntax AS between a column/function name and its alias
				in a column select list

				columnAliasQuote
				What character to use to quote a column alias, usually ' or "

				wildCard
				What character to use as a wildcard in LIKE conditions, usually % or *

				secondDP
				The number of decimal digits permitted in seconds in TIME, TIMESTAMP and
				DATETIME types.
			*/
			struct tagLanguage
			{
				Database database;
				Schema schema;
				CaseSensitivity caseSensitivity;
				bool escapeQuote;
				bool escapeSlash;
				bool columnAliasAs;
				char columnAliasQuote;
				char wildCard;
				int secondDP;
			};

		private:
			struct tagLanguage _language;
			std::string _strColumnAliasQuote;
			std::string _strWildCard;

		public:
			SqlLanguage( struct tagLanguage& language );
			SqlLanguage( Database database, Schema schema, CaseSensitivity caseSensitivity,
							bool escapeQuote, bool escapeSlash,
							bool columnAliasAs, char columnAliasQuote, char wildCard, int secondDP );

			virtual ~SqlLanguage();

			Database database() const;
			Schema schema() const;
			CaseSensitivity caseSensitivity() const;
			bool escapeQuote() const;
			bool escapeSlash() const;
			bool columnAliasAs() const;
			const std::string& columnAliasQuote() const;
			const std::string& wildCard() const;
			int secondDP() const;

			const SqlLanguage& operator=( const SqlLanguage& language );

		protected:
			void copy( const struct tagLanguage& language );
			SqlLanguage();
	};
};

#endif /* !__SqlLanguage_h__ */
