/*
	$Id: SqlLogger.h 1180 2018-11-14 17:41:31Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2011, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

/*
	It is preferable that the construction of a logger should not be able to fail, however, sh*t
	happens. The default constructor adds the Logger to the Logger queue and the default destructor
	removes it. This means that if construction of the derived object fails, the logger is in
	the logger queue in a non-functional state.

	In this event, the logger should call deregisterLogger() to remove itself from the queue. Then,
	and only then, should it throw an exception. The correct Exception (oddly) is a
	DalDatabaseException with an error code of DDBERR_LOGGERCREATIONFAILED. In this way it is
	possible to also pass back a native error code and a native explanation. See SqlLoggerFile for
	more information...
*/

#ifndef __SqlLogger_h__
#define __SqlLogger_h__

#include <librfcdal/SqlGlobal.h>

#include <string>
#include <set>

namespace RfcDal
{
	class RFCDAL_EXPORT SqlLogger
	{
		public:
			enum Level { logNothing, logExceptions, logWarnings, logDebugs, logTraces };
			
			class RFCDAL_EXPORT SqlLoggerSet : public std::set<SqlLogger*>
			{
			};

		private:
			static SqlLoggerSet _loggerS;
			Level _level;

		public:
			SqlLogger();
			virtual ~SqlLogger();

			void setLogLevel( Level level );
			Level logLevel();

			static void logException( const std::string& strLegend );
			static void logWarning( const std::string& strLegend );
			static void logDebug( const std::string& strLegend );
			static void logTrace( const std::string& strLegend );

		protected:
			void deregisterLogger();

			virtual void logExceptionReal( const std::string& strLegend ) const = 0;
			virtual void logWarningReal( const std::string& strLegend ) const = 0;
			virtual void logDebugReal( const std::string& strLegend ) const = 0;
	};
};

#endif /* !__SqlLogger_h__ */
