/*
	$Id: SqlQueryBase.h 1186 2018-11-15 15:12:44Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlQueryBase_h__
#define __SqlQueryBase_h__

#include <librfcdal/DalDatabase.h>
#include <librfcdal/DalDatabaseException.h>
#include <librfcdal/SqlException.h>
#include <librfcdal/SqlColumn.h>

#include <librfcdal/CSVParser.h>
#include <librfcdal/SqlMapper.h>
#include <librfcdal/SqlColumnInfo.h>

#include <map>
#include <string>

namespace RfcDal
{
	class SqlColumnarStatement;

	class RFCDAL_EXPORT SqlQueryBase
	{
		public:
			enum ValueValidity { validOnly = 0, invalidToo = 1 };
			enum QueryType { brief, full, min, max, count };

		private:
			SqlColumnMap _columnS;

		public:
			SqlQueryBase();
			virtual ~SqlQueryBase();

			// should be abstract to force override, but implemented so as not to upset older DALs.
			virtual const RfcDal::SqlTable& table() const;

			void addColumn( SqlColumn& column );
			void addColumns( SqlColumnarStatement& statement, ValueValidity validity );
			SqlColumn& column( const std::string& strId );
			const SqlColumnMap& columns() const;

			void clear();
			int loadFromRow( const DalDatabase::Row& row );
			int loadFromRow( const DalDatabase::Row& row, const SqlMapper::ColumnMap& columnS );
			int loadFromRow( const CSVParser::Row& row, const SqlMapper::FieldMap& fieldS, const SqlQueryInfo& info );

			virtual int select( DalDatabase::Result&, DalDatabase&, QueryType ) = 0;
			virtual int insert( DalDatabase& ) = 0;
			virtual int update( DalDatabase& ) = 0;
			virtual int remove( DalDatabase& ) = 0;
	};
};

#endif /* !__SqlQueryBase_h__ */
