/*
	$Id: SqlReal.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2009, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlReal_h__
#define __SqlReal_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlValue.h>

#include <string>

#define SQLREAL_USE_LONGDOUBLE

namespace RfcDal
{
	const int SqlRealMaxMagnitude( 32 );
	const int SqlRealMaxDecimals( 32 );
	const int SqlRealDefaultDecimals( -1 );

	class RFCDAL_EXPORT SqlReal : public SqlValue
	{
		public:
#if defined (SQLREAL_USE_LONGDOUBLE)
			typedef long double SqlDouble;
#else
			typedef double SqlDouble;
#endif /* SQLREAL_USE_LONGDOUBLE */

		private:
			SqlDouble _dValue;
			int _nDP;

		public:
			SqlReal( const SqlReal& real, const std::string& strAlias = "" );
			SqlReal( SqlDouble dValue, const std::string& strAlias = "" );
			virtual ~SqlReal();

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			virtual SqlValue* copy() const;

			SqlDouble value() const;

			const SqlReal& operator=( const SqlReal& real );

			void setDecimalPlaces( int nDP );

			static SqlReal fromText( const std::string& strText );
	};
};

#endif /* !__SqlReal_h__ */
