/*
	$Id: SqlSchema.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlSchema_h__ 
#define __SqlSchema_h__ 

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlElement.h>
#include <librfcdal/SqlLanguage.h>
#include <librfcdal/SqlUtil.h>
#include <librfcdal/SqlDatabase.h>

#include <string>
#include <vector>

namespace RfcDal
{
	class RFCDAL_EXPORT SqlSchema : public SqlElement
	{
		private:
			bool _bIsNull;
			SqlDatabase _database;
			std::string _strSchema;

		public:
			SqlSchema();
			SqlSchema( const SqlSchema& schema );
			SqlSchema( const std::string& strSchema );
			SqlSchema( const SqlDatabase& database );
			SqlSchema( const SqlDatabase& database, const std::string& strSchema );
			virtual ~SqlSchema();

			bool isNull() const;
			const SqlDatabase& database() const;
			const std::string& schema() const;

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			const SqlSchema& operator=( const SqlSchema& schema );
	};

	class SqlSchemaList : public std::vector<SqlSchema>
	{
	};
};

#endif /* !__SqlSchema_h__  */
