/*
	$Id: SqlSelectStatement.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlSelectStatement_h__
#define __SqlSelectStatement_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlQueryStatement.h>
#include <librfcdal/SqlColumnarStatement.h>
#include <librfcdal/SqlConditionPtr.h>
#include <librfcdal/SqlTable.h>
#include <librfcdal/SqlColumnPtr.h>
#include <librfcdal/SqlJoin.h>
#include <librfcdal/SqlOrder.h>
#include <librfcdal/SqlGroup.h>
#include <librfcdal/SqlLimit.h>

#include <vector>

namespace RfcDal
{
	class RFCDAL_EXPORT SqlSelectStatement : public SqlQueryStatement, public SqlColumnarStatement
	{
		private:
			SqlTableList _tableS;
			SqlConditionPtr _pwhere;
			SqlJoinList _joinS;
			SqlOrderList _orderS;
			SqlGroupList _groupS;
			SqlConditionPtr _phaving;
			SqlLimit _limit;

		public:
			SqlSelectStatement();
			SqlSelectStatement( const SqlSelectStatement& stmt );
			SqlSelectStatement( const SqlTable& table );
			virtual ~SqlSelectStatement();

			const SqlSelectStatement& operator=( const SqlSelectStatement& stmt );

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			virtual const SqlAbstractColumn& column( unsigned uIndex ) const;

			void addTable( const SqlTable& table );
			void setWhere( const SqlConditionPtr& condition );
			void addJoin( const SqlJoin& join );
			void addOrder( const SqlOrder& order );
			void addGroup( const SqlGroup& group );
			void setHaving( const SqlConditionPtr& condition );
			void setLimit( const SqlLimit& limit );
	};
};

#endif /* !__SqlSelectStatement_h__ */
