/*
	$Id: SqlTable.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlTable_h__
#define __SqlTable_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlElement.h>
#include <librfcdal/SqlDatabase.h>
#include <librfcdal/SqlSchema.h>

#include <string>
#include <vector>

namespace RfcDal
{
	class RFCDAL_EXPORT SqlTable : public SqlElement
	{
		private:
			SqlSchema _schema;
			std::string _strTable;
			std::string _strAlias;

		public:
			static const SqlTable dual;

		public:
			SqlTable();
			SqlTable( const SqlTable& table );
			SqlTable( const std::string& strTable, const std::string& strAlias = std::string() );
			SqlTable( const SqlSchema& schema, const std::string& strTable, const std::string& strAlias = std::string() );
			virtual ~SqlTable();

			const SqlSchema& schema() const;
			const std::string& table() const;
			const std::string& alias() const;

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			const SqlTable& operator=( const SqlTable& table );
	};

	class SqlTableList : public std::vector<SqlTable>
	{
	};
};

#endif /* !__SqlTable_h__ */
