/*
	$Id: SqlTime.h 1241 2018-12-03 15:54:49Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2009, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlTime_h__
#define __SqlTime_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlValue.h>

#include <string>

namespace Base4c
{
	class Time;
}

namespace RfcDal
{
	class RFCDAL_EXPORT SqlTime : public SqlValue
	{
		private:
			int _nHour;
			int _nMinute;
			double _dSecond;

		public:
			SqlTime( const std::string& strAlias = std::string() );
			SqlTime( int nHour, int nMinute, double dSecond, const std::string& strAlias = std::string() );
			SqlTime( const SqlTime& time, const std::string& strAlias = std::string() );
			virtual ~SqlTime();

			const SqlTime& operator=( const SqlTime& time );

			bool operator==( const SqlTime& time ) const;

			int hour() const;
			int minute() const;
			double second() const;

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			virtual SqlValue* copy() const;

			static SqlTime fromText( const std::string& strText );

			static SqlTime fromTime( const Base4c::Time& tm, const std::string& strAlias = std::string() );
			Base4c::Time asTime();
	};
};

#endif /* !__SqlTime_h__ */
