/*
	$Id: SqlTimestamp.h 1241 2018-12-03 15:54:49Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2009, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlTimestamp_h__
#define __SqlTimestamp_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlTime.h>
#include <librfcdal/SqlDate.h>

namespace Base4c
{
	class Timestamp;
}

namespace RfcDal
{
	class RFCDAL_EXPORT SqlTimestamp : public SqlValue
	{
		public:
			static const SqlTimestamp eternity;

		private:
			SqlDate _date;
			SqlTime _time;
			
		public:
			SqlTimestamp( const std::string& strAlias = std::string() );
			SqlTimestamp( int nYear, int nMonth, int nDay, int nHour, int nMinute, int nSecond, const std::string& strAlias = std::string() );
			SqlTimestamp( int nYear, int nMonth, int nDay, int nHour, int nMinute, double dSecond, const std::string& strAlias = std::string() );
			SqlTimestamp( const SqlTimestamp& stamp, const std::string& strAlias = std::string() );
			SqlTimestamp( const SqlDate& date, const SqlTime& time, const std::string& strAlias = std::string() );
			virtual ~SqlTimestamp();

			const SqlTimestamp& operator=( const SqlTimestamp& stamp );

			bool operator==( const SqlTimestamp& stamp ) const;

			int year() const;
			int month() const;
			int day() const;
			int hour() const;
			int minute() const;
			double second() const;

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			virtual SqlValue* copy() const;

			static SqlTimestamp fromText( const std::string& strText );

			static SqlTimestamp fromTimestamp( const Base4c::Timestamp& ts, const std::string& strAlias = std::string() );
			Base4c::Timestamp asTimestamp();
	};
}

#endif /* !__SqlTimestamp_h__ */
