/*
	$Id: SqlValue.h 1177 2018-11-14 16:17:27Z john $

	This file is part of the RFC DAL.

	The RFC DAL is Copyright (c) 2004 - 2007, The 4c Company.

	The RFC DAL is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, version 2 of the License.

	The RFC DAL is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with This code.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __SqlValue_h__
#define __SqlValue_h__

#include <librfcdal/SqlGlobal.h>
#include <librfcdal/SqlAbstractColumn.h>
#include <librfcdal/SqlColumnInfo.h>

#include <vector>

namespace RfcDal
{
	class SqlTable;

	class RFCDAL_EXPORT SqlValue : public SqlAbstractColumn
	{
		private:
			static bool _bctxDefaultPermitted;
			SqlColumnInfo::Bind _bind;
			bool _bSuppressQuotes;
			std::string _strValue;
			SqlValue* _pvalue;
			std::string _strAlias;
			const SqlTable* _ptable;
			bool _bIsValid;

		public:
			SqlValue();
			SqlValue( const SqlValue& value );
			SqlValue( const std::string& strValue, SqlColumnInfo::Bind bind );
			SqlValue( const std::string& strValue, bool bSuppressQuotes = false );
			SqlValue( const double& dValue );
			SqlValue( int lValue );
			SqlValue( unsigned int ulValue );
			SqlValue( const std::string& strValue, const std::string& strAlias, bool bSuppressQuotes = false );
			SqlValue( const double& dValue, const std::string& strAlias );
			SqlValue( int lValue, const std::string& strAlias );
			SqlValue( unsigned int ulValue, const std::string& strAlias );
			virtual ~SqlValue();

			bool isValid() const;

			const SqlValue& operator=( const std::string& strValue );
			const SqlValue& operator=( const double& dValue );
			const SqlValue& operator=( int lValue );
			const SqlValue& operator=( unsigned int ulValue );
			const SqlValue& operator=( const SqlValue& value );

			void setValue( const std::string& strValue );
			void setValue( const double& dValue );
			void setValue( int lValue );
			void setValue( unsigned int ulValue );
			void setValue( const SqlValue& value );

			operator const std::string&() const;
			operator const char*() const;
			operator double() const;
			operator int() const;
			operator unsigned int() const;

			const std::string& string() const;
			const char* c_str() const;
			double asDouble() const;
			int asInt() const;
			unsigned int asUnsigned() const;

			virtual std::string id() const;

			virtual std::string toSql( const SqlLanguage& language, const SqlAliasSet& aliasS = SqlAliasSet(), Context context = ctxDefault ) const;

			virtual SqlValue* copy() const;

			SqlColumnInfo::Bind bound() const;

			static bool ctxDefaultPermitted();
			static void setctxDefaultPermitted( bool bPermitted );

		protected:
			const std::string& alias() const;
			void alias( const std::string& strAlias );

		protected:
			friend class SqlColumn;
	};

	class SqlValueList : public std::vector<SqlValue>
	{
	};
};

#endif /* !__SqlValue_h__ */
